package com.aucma.base.mapper;

import java.util.List;
import com.aucma.base.domain.SamplingInspection;

public interface SamplingInspectionMapper {
    public SamplingInspection selectSamplingInspectionByObjId(Long objId);

    public List<SamplingInspection> selectSamplingInspectionList(SamplingInspection samplingInspection);

    public int insertSamplingInspection(SamplingInspection samplingInspection);

    public int updateSamplingInspection(SamplingInspection samplingInspection);

    public int deleteSamplingInspectionByObjId(Long objId);

    public int deleteSamplingInspectionByObjIds(Long[] objIds);
}
