package com.aucma.base.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.aucma.common.utils.DateUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.aucma.common.annotation.Log;
import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.enums.BusinessType;
import com.aucma.base.domain.SamplingInspection;
import com.aucma.base.service.ISamplingInspectionService;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.common.core.page.TableDataInfo;

@RestController
@RequestMapping("/base/samplingInspection" )
public class SamplingInspectionController extends BaseController {
    @Autowired
    private ISamplingInspectionService samplingInspectionService;

    @PreAuthorize("@ss.hasPermi('base:samplingInspection:list')" )
    @GetMapping("/list" )
    public TableDataInfo list(SamplingInspection samplingInspection) {
        startPage();
        List<SamplingInspection> list = samplingInspectionService.selectSamplingInspectionList(samplingInspection);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('base:samplingInspection:export')" )
    @Log(title = "抽样检验" , businessType = BusinessType.EXPORT)
    @PostMapping("/export" )
    public void export(HttpServletResponse response, SamplingInspection samplingInspection) {
        List<SamplingInspection> list = samplingInspectionService.selectSamplingInspectionList(samplingInspection);
        ExcelUtil<SamplingInspection> util = new ExcelUtil<SamplingInspection>(SamplingInspection. class);
        util.exportExcel(response, list, "抽样检验数据" );
    }

    @PreAuthorize("@ss.hasPermi('base:samplingInspection:query')" )
    @GetMapping(value = "/{objId}" )
    public AjaxResult getInfo(@PathVariable("objId" ) Long objId) {
        return success(samplingInspectionService.selectSamplingInspectionByObjId(objId));
    }

    @PreAuthorize("@ss.hasPermi('base:samplingInspection:add')" )
    @Log(title = "抽样检验" , businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SamplingInspection samplingInspection) {
        samplingInspection.setCreatedTime(DateUtils.getNowDate());
        return toAjax(samplingInspectionService.insertSamplingInspection(samplingInspection));
    }

    @PreAuthorize("@ss.hasPermi('base:samplingInspection:edit')" )
    @Log(title = "抽样检验" , businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SamplingInspection samplingInspection) {
        samplingInspection.setUpdatedTime(DateUtils.getNowDate());
        return toAjax(samplingInspectionService.updateSamplingInspection(samplingInspection));
    }

    @PreAuthorize("@ss.hasPermi('base:samplingInspection:remove')" )
    @Log(title = "抽样检验" , businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}" )
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(samplingInspectionService.deleteSamplingInspectionByObjIds(objIds));
    }

    @PreAuthorize("@ss.hasPermi('base:samplingInspection:list')" )
    @GetMapping("/getList" )
    public TableDataInfo getList(SamplingInspection samplingInspection) {
        List<SamplingInspection> list = samplingInspectionService.selectSamplingInspectionList(samplingInspection);
        return getDataTable(list);
    }
}
